@@ -8,8 +8,12 @@ sub find_by_id($self, $id) {
 }
 
 sub account_for($self, $user) {
+  return $self->find_account($user->id);
+}
+
+sub find_account($self, $id) {
   my $account = $self->find(
-    { 'me.id' => $user->id },
+    { 'me.id' => $id },
     { prefetch => ['profile', {profile=>'state'}, {profile=>'employment'}, 'credit_cards', {person_roles => 'role' }] }
   );
   $account->build_related_if_empty('profile'); # Needed since the relationship is optional
@@ -18,6 +22,13 @@ sub account_for($self, $user) {
   return $account;
 }
 
+sub accessible_people_for($self, $user) {
+  # For now a user can only access themselves
+  return $self->search(
+    { 'me.id' => $user->id },
+  );
+} 
+
 sub unauthenticated_user($self, $args=+{}) {
   return $self->new_result($args);  
 }
